@@ -46,14 +46,14 @@ from .pbs import PBS
 from .pbs import Torque
 from .shell import Shell
 from .lsf import LSF
-from .dp_cloud_server import DpCloudServer
+from .dp_cloud_server import DpCloudServer, Lebesgue
 from .distributed_shell import DistributedShell
 from .machine import Machine
 
 from .lazy_local_context import LazyLocalContext
 from .local_context import LocalContext
 from .ssh_context import SSHContext
-from .dp_cloud_server_context import DpCloudServerContext
+from .dp_cloud_server_context import DpCloudServerContext, LebesgueContext
 from .hdfs_context import HDFSContext
 
 def info():
