@@ -1,5 +1,7 @@
 import os
 import json
+import time
+
 try:
     import oss2
     from oss2 import SizedFileAdapter, determine_part_size
@@ -23,44 +25,70 @@ class API:
 
     def get(self, url, params, retry=0):
         headers = {'Authorization': "jwt " + self._token}
-        ret = requests.get(
-            urljoin(API_HOST, url),
-            params=params,
-            timeout=HTTP_TIME_OUT,
-            headers=headers
-        )
+        ret = None
+        for retry_count in range(3):
+            try:
+                ret = requests.get(
+                    urljoin(API_HOST, url),
+                    params=params,
+                    timeout=HTTP_TIME_OUT,
+                    headers=headers
+                )
+            except Exception as e:
+                dlog.error(f"request error {e}")
+                continue
+            if ret.ok:
+                break
+            else:
+                dlog.error(f"request error status_code:{ret.status_code} reason: {ret.reason} body: \n{ret.text}")
+                time.sleep(retry_count * 10)
+        if ret is None:
+            raise ConnectionError("request fail")
         # print(url,'>>>', params, '<<<', ret.text)
+        ret.raise_for_status()
         ret = json.loads(ret.text)
         if ret['code'] == RETCODE.TOKENINVALID and retry <= 3:
-            dlog.debug("debug: token expire, refresh token")
+            dlog.info("debug: token expire, refresh token")
             if self._login_data is not None:
                 self.refresh_token()
                 ret = self.get(url, params, retry=retry + 1)
                 return ret
         if ret['code'] != RETCODE.OK:
             raise ValueError(f"{url} Error: {ret['code']} {ret['message']}")
-
         return ret['data']
 
     def post(self, url, params, retry=0):
         headers = {'Authorization': "jwt " + self._token}
-        ret = requests.post(
-            urljoin(API_HOST, url),
-            json=params,
-            timeout=HTTP_TIME_OUT,
-            headers=headers
-        )
-        # print(url,'>>>', params, '<<<', ret.text)
+        ret = None
+        for retry_count in range(3):
+            try:
+                ret = requests.post(
+                    urljoin(API_HOST, url),
+                    json=params,
+                    timeout=HTTP_TIME_OUT,
+                    headers=headers
+                )
+            except Exception as e:
+                dlog.error(f"request error {e}")
+                continue
+            if ret.ok:
+                break
+            else:
+                dlog.error(f"request error status_code:{ret.status_code} reason: {ret.reason} body: \n{ret.text}")
+                time.sleep(retry_count)
+        if ret is None:
+            raise ConnectionError("request fail")
+        ret.raise_for_status()
         ret = json.loads(ret.text)
+        # print(url,'>>>', params, '<<<', ret.text)
         if ret['code'] == RETCODE.TOKENINVALID and retry <= 3:
-            dlog.debug("debug: token expire, refresh token")
+            dlog.info("debug: token expire, refresh token")
             if self._login_data is not None:
                 self.refresh_token()
                 ret = self.post(url, params, retry=retry + 1)
                 return ret
         if ret['code'] != RETCODE.OK:
             raise ValueError(f"{url} Error: {ret['code']} {ret['message']}")
-
         return ret['data']
 
     def refresh_token(self):
@@ -94,6 +122,32 @@ class API:
         bucket.get_object_to_file(oss_file, save_file)
         return save_file
 
+    def download_from_url(self, url, save_file):
+        ret = None
+        for retry_count in range(3):
+            try:
+                ret = requests.get(
+                    url,
+                    headers={'Authorization': "jwt " + self._token},
+                    stream=True
+                )
+            except Exception as e:
+                dlog.error(f"request error {e}")
+                continue
+            if ret.ok:
+                break
+            else:
+                dlog.error(f"request error status_code:{ret.status_code} reason: {ret.reason} body: \n{ret.text}")
+                time.sleep(retry_count)
+                ret = None
+        if ret is not None:
+            ret.raise_for_status()
+            with open(save_file, 'wb') as f:
+                for chunk in ret.iter_content(chunk_size=8192):
+                    f.write(chunk)
+            ret.close()
+
+
     def upload(self, oss_task_zip, zip_task_file, endpoint, bucket_name):
         dlog.debug(f"debug: upload: oss_task_zip:{oss_task_zip}; zip_task_file:{zip_task_file}")
         bucket = self._get_oss_bucket(endpoint, bucket_name)
@@ -116,18 +170,8 @@ class API:
         # print('debug:upload_result:', result, dir())
         return result
 
-    def job_create(self, job_type, oss_path, input_data, program_id=None):
-        post_data = {
-            'job_type': job_type,
-            'oss_path': oss_path,
-            'input_data': input_data,
-        }
-        if program_id is not None:
-            post_data["program_id"] = program_id
-        ret = self.post('/data/insert_job', post_data)
-        return ret['job_id']
 
-    def job_create_v2(self, job_type, oss_path, input_data, program_id=None, group_id=None):
+    def job_create(self, job_type, oss_path, input_data, program_id=None, group_id=None):
         post_data = {
             'job_type': job_type,
             'oss_path': oss_path,
@@ -156,17 +200,7 @@ class API:
         )
         return ret['items']
 
-    def get_tasks(self, job_id, page=1, per_page=10):
-        ret = self.get(
-            f'data/job/{job_id}/tasks',
-            {
-                'page': page,
-                'per_page': per_page,
-            }
-        )
-        return ret['items']
-
-    def get_tasks_v2(self, job_id, group_id, page=1, per_page=10):
+    def get_tasks(self, job_id, group_id, page=1, per_page=10):
         ret = self.get(
             f'data/job/{group_id}/tasks',
             {
@@ -176,9 +210,61 @@ class API:
         )
         for each in ret['items']:
             if job_id == each["task_id"]:
-                return [each]
+                return each
         if len(ret['items']) != 0:
-            return self.get_tasks_v2(job_id, group_id, page=page + 1)
-        return []
+            return self.get_tasks(job_id, group_id, page=page + 1)
+        return None
+
+    def get_tasks_list(self, group_id, per_page=30):
+        result = []
+        page = 0
+        while True:
+            ret = self.get(
+                f'data/job/{group_id}/tasks',
+                {
+                    'page': page,
+                    'per_page': per_page,
+                }
+            )
+            if len(ret['items']) == 0:
+                break
+            for each in ret['items']:
+                result.append(each)
+            page += 1
+        return result
+
+    def check_job_has_uploaded(self, job_id):
+        try:
+            if not job_id:
+                return False
+            if 'job_group_id' in job_id:
+                ids = job_id.split(":job_group_id:")
+                job_id, _ = int(ids[0]), int(ids[1])
+            ret = self.get(f'data/job/{job_id}', {})
+            if len(ret) == 0:
+                return False
+            if ret.get('input_data'):
+                return True
+            else:
+                return False
+        except ValueError as e:
+            dlog.error(e)
+            return False
+
+    def get_job_result_url(self, job_id):
+        try:
+            if not job_id:
+                return None
+            if 'job_group_id' in job_id:
+                ids = job_id.split(":job_group_id:")
+                job_id, _ = int(ids[0]), int(ids[1])
+            ret = self.get(f'data/job/{job_id}', {})
+            if 'result_url' in ret and len(ret['result_url']) != 0:
+                return ret.get('result_url')
+            else:
+                return None
+        except ValueError as e:
+            dlog.error(e)
+            return None
 
 # %%
