@@ -31,6 +31,8 @@ class LazyLocalContext(BaseContext) :
         remote_profile:
         """
         assert(type(local_root) == str)
+        self.init_local_root = local_root
+        self.init_remote_root = remote_root
         self.temp_local_root = os.path.abspath(local_root)
         self.temp_remote_root = os.path.abspath(local_root)
         self.remote_profile = remote_profile
