@@ -55,6 +55,8 @@ class LocalContext(BaseContext) :
         remote_profile:
         """
         assert(type(local_root) == str)
+        self.init_local_root = local_root
+        self.init_remote_root = remote_root
         self.temp_local_root = os.path.abspath(local_root)
         self.temp_remote_root = os.path.abspath(remote_root)
         self.remote_profile = remote_profile
