@@ -7,6 +7,7 @@ import uuid
 from glob import glob
 from dpdispatcher import dlog
 from dargs.dargs import Argument
+from typing import List
 import pathlib
 # from dpdispatcher.submission import Machine
 from dpdispatcher.utils import get_sha256, generate_totp
@@ -185,9 +186,12 @@ class SSHContext(BaseContext):
                 **kwargs,
                 ):
         assert(type(local_root) == str)
+        self.init_local_root = local_root
+        self.init_remote_root = remote_root
         self.temp_local_root = os.path.abspath(local_root)
         assert os.path.isabs(remote_root), f"remote_root must be a abspath"
         self.temp_remote_root = remote_root
+        self.remote_profile = remote_profile
 
         # self.job_uuid = None
         self.clean_asynchronously = clean_asynchronously
@@ -257,6 +261,12 @@ class SSHContext(BaseContext):
         # self.remote_root = os.path.join(self.temp_remote_root, self.submission.submission_hash, self.submission.work_base )
         self.remote_root = pathlib.PurePath(os.path.join(self.temp_remote_root, self.submission.submission_hash)).as_posix()
 
+        sftp = self.ssh_session.ssh.open_sftp()
+        try:
+            sftp.mkdir(self.remote_root)
+        except OSError:
+            pass
+
         # self.job_uuid = submission.submission_hash
         # dlog.debug("debug:SSHContext.bind_submission"
         #     "{submission.submission_hash}; {self.local_root}; {self.remote_root")
@@ -329,12 +339,14 @@ class SSHContext(BaseContext):
             self.write_file(sha256_file, "\n".join(sha256_list))
             # check sha256
             # `:` means pass: https://stackoverflow.com/a/2421592/9567349
-            _, stdout, _ = self.block_checkcall("sha256sum -c %s --quiet || :" % sha256_file)
+            _, stdout, _ = self.block_checkcall("sha256sum -c %s --quiet >.sha256sum_stdout 2>/dev/null || :" % sha256_file)
             self.sftp.remove(sha256_file)
             # regenerate file list
             file_list = []
-            for ii in stdout:
-                file_list.append(ii.split(":")[0])
+
+            for ii in self.read_file(".sha256sum_stdout").split("\n"):
+                if ii:
+                    file_list.append(ii.split(":")[0])
         else:
             # convert to relative path to local_root
             file_list = [os.path.relpath(jj, self.local_root) for jj in file_list] 
@@ -490,7 +502,7 @@ class SSHContext(BaseContext):
         os.chdir(self.local_root)
         if os.path.isfile(of) :
             os.remove(of)
-        with tarfile.open(of, "w:gz", dereference = dereference) as tar:
+        with tarfile.open(of, "w:gz", dereference = dereference, compresslevel=6) as tar:
             for ii in files :
                 tar.add(ii)
             if directories is not None:
@@ -557,3 +569,18 @@ class SSHContext(BaseContext):
         # cleanup
         os.remove(to_f)
         self.sftp.remove(from_f)
+
+    @classmethod
+    def machine_subfields(cls) -> List[Argument]:
+        """Generate the machine subfields.
+        
+        Returns
+        -------
+        list[Argument]
+            machine subfields
+        """
+        doc_remote_profile = 'The information used to maintain the connection with remote machine.'
+        remote_profile_format = SSHSession.arginfo()
+        remote_profile_format.name = "remote_profile"
+        remote_profile_format.doc = doc_remote_profile
+        return [remote_profile_format]
